boto v2.22.0 — boto v2.27.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »

# boto v2.22.0

date: | 2014/01/02

This release updates the Auto Scaling to support the latest API, the ability to control the response sizes in Amazon DynamoDB queries/scans & a number of bugfixes as well.

## Features

- Updated Auto Scaling to support the latest API. (commit 9984c4f)
- Added the ability to alter response sizes in DynamoDB queries/scans. (issue 1949, commit 6761b01)

## Bugfixes

- Fix string instance tests. (issue 1959, commit ee203bf)
- Add missing parameters to `get_spot_price_history method`. (issue 1958, commit f635474)
- Fix unicode string parameter handling in S3Connection. (issue 1954, issue 1952, commit 12e6b0c)
- Fix typo in docstring for SSHClient.run. (issue 1953, commit 5263b20)
- Properly handle getopt long options in s3put. (issue 1950, issue 1946, commit cf693ff)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »